<?php
/**
 * Sample code for the CreatePickupRequest Canada Post service.
 * 
 * The CreatePickupRequest service creates a request for a one-time on-demand pickup or to set up scheduled pickups.
 * 
 * This sample is configured to access the Developer Program sandbox environment. 
 * Use your development key username and password for the web service credentials.
 * 
 */

// Your username and password are imported from the following file
// CPCWS_Pickup_PHP_Samples\REST\pickup\user.ini
$userProperties = parse_ini_file(realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../user.ini');

$username = $userProperties['username']; 
$password = $userProperties['password'];
$customer = $userProperties['customerNumber'];

// REST URI
$service_url = 'https://stg30.soa-gw.canadapost.ca/enab/' . $customer . '/pickuprequest';

$xmlRequest = <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<pickup-request-details xmlns="http://www.canadapost.ca/ws/pickuprequest">
    <pickup-type>OnDemand</pickup-type>
    <pickup-location>
       <business-address-flag>true</business-address-flag>
    </pickup-location>
    <contact-info>
       <contact-name>John Smith</contact-name>
       <email>john.smith@host.com</email>
       <contact-phone>613-123-4567</contact-phone>
    </contact-info>
    <location-details>
    	<pickup-instructions>Door at back.</pickup-instructions>
    </location-details>
    <pickup-volume>50 parcels, 10 packets</pickup-volume>
    <pickup-times>
       <on-demand-pickup-time>
          <date>2015-05-07</date>
          <preferred-time>16:00</preferred-time>
          <closing-time>17:00</closing-time>
       </on-demand-pickup-time>
    </pickup-times>
    <payment-info>
       <method-of-payment>Account</method-of-payment>
    </payment-info>
</pickup-request-details>
XML;

$curl = curl_init($service_url); // Create REST Request
curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, true);
curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 2); 
curl_setopt($curl, CURLOPT_CAINFO, realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../../../third-party/cert/cacert.pem'); // Mozilla cacerts
curl_setopt($curl, CURLOPT_POST, true);
curl_setopt($curl, CURLOPT_POSTFIELDS, $xmlRequest);
curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
curl_setopt($curl, CURLOPT_USERPWD, $username . ':' . $password);
curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type: application/vnd.cpc.pickuprequest+xml', 'Accept:application/vnd.cpc.pickuprequest+xml', 'Accept-Language:en-CA'));
$curl_response = curl_exec($curl); // Execute REST Request
if(curl_errno($curl)){
	echo 'Curl error: ' . curl_error($curl) . "\n";
}

echo 'HTTP Response Status: ' . curl_getinfo($curl,CURLINFO_HTTP_CODE) . "\n";

// Example of using SimpleXML to parse xml response
libxml_use_internal_errors(true);
$xml = simplexml_load_string('<root>' . preg_replace('/<\?xml.*\?>/','',$curl_response) . '</root>');
//var_dump($xml);

if (!$xml) {
	echo 'Failed loading XML' . "\n";
	echo $curl_response . "\n";
	foreach(libxml_get_errors() as $error) {
		echo "\t" . $error->message;
	}
} else {
	if ($xml->{'pickup-request-info'} ) {
		$pickup = $xml->{'pickup-request-info'}->children('http://www.canadapost.ca/ws/pickuprequest');
		$header = $pickup->{'pickup-request-header'};
		
        echo  'Request Id: ' . $header->{'request-id'} . "\n";
        echo  'Request Status: ' . $header->{'request-status'} . "\n";
        echo  'Pickup Type: ' . $header->{'pickup-type'} . "\n";
        echo  'Request Date: ' . $header->{'request-date'} . "\n";
		foreach ( $pickup->{'links'}->{'link'} as $link ) {  
			echo $link->attributes()->{'rel'} . ': ' . $link->attributes()->{'href'} . "\n";
		}
	}
	if ($xml->{'messages'} ) {					
		$messages = $xml->{'messages'}->children('http://www.canadapost.ca/ws/messages');		
		foreach ( $messages as $message ) {
			echo 'Error Code: ' . $message->code . "\n";
			echo 'Error Msg: ' . $message->description . "\n\n";
		}
	}
}

curl_close($curl);
?>

